@@ -94,12 +94,19 @@ class ALNS:
         """
         Adds a destroy operator to the heuristic instance.
 
+        .. warning::
+
+            A destroy operator will receive the current solution state
+            maintained by the ALNS instance, not a copy. Make sure to modify
+            a **copy** of this state in the destroy operator, created using,
+            for example, :func:`copy.copy` or :func:`copy.deepcopy`.
+
         Parameters
         ----------
         op
             An operator that, when applied to the current state, returns a new
-            state reflecting its implemented destroy action. The second
-            argument is the random state constructed from the passed-in seed.
+            state reflecting its implemented destroy action. Its second
+            argument is the random state passed to the ALNS instance.
         name
             Optional name argument, naming the operator. When not passed, the
             function name is used instead.
@@ -117,8 +124,8 @@ class ALNS:
         ----------
         op
             An operator that, when applied to the destroyed state, returns a
-            new state reflecting its implemented repair action. The second
-            argument is the random state constructed from the passed-in seed.
+            new state reflecting its implemented repair action. Its second
+            argument is the random state passed to the ALNS instance.
         name
             Optional name argument, naming the operator. When not passed, the
             function name is used instead.
@@ -176,7 +183,7 @@ class ALNS:
 
         .. [2] S. Røpke and D. Pisinger (2006). A unified heuristic for a large
                class of vehicle routing problems with backhauls. *European
-               Journal of Operational Research*, 171: 750–775, 2006.
+               Journal of Operational Research*, 171: 750–775.
         """
         if len(self.destroy_operators) == 0 or len(self.repair_operators) == 0:
             raise ValueError("Missing destroy or repair operators.")
@@ -219,8 +226,7 @@ class ALNS:
     def on_best(self, func: _CallbackType):
         """
         Sets a callback function to be called when ALNS finds a new global best
-        solution state. The solution returned by the callback is *not*
-        evaluated again.
+        solution state.
         """
         logger.debug(f"Adding on_best callback {func.__name__}.")
         self._on_outcome[Outcome.BEST] = func
@@ -228,8 +234,7 @@ class ALNS:
     def on_better(self, func: _CallbackType):
         """
         Sets a callback function to be called when ALNS finds a better solution
-        than the current incumbent. The solution returned by the callback is
-        *not* evaluated again.
+        than the current incumbent.
         """
         logger.debug(f"Adding on_better callback {func.__name__}.")
         self._on_outcome[Outcome.BETTER] = func
@@ -238,8 +243,7 @@ class ALNS:
         """
         Sets a callback function to be called when ALNS accepts a new solution
         as the current incumbent (that is not a new global best, or otherwise
-        improving). The solution returned by the callback is *not* evaluated
-        again.
+        improving).
         """
         logger.debug(f"Adding on_accept callback {func.__name__}.")
         self._on_outcome[Outcome.ACCEPT] = func
@@ -247,7 +251,6 @@ class ALNS:
     def on_reject(self, func: _CallbackType):
         """
         Sets a callback function to be called when ALNS rejects a new solution.
-        The solution returned by the callback is *not* evaluated again.
         """
         logger.debug(f"Adding on_reject callback {func.__name__}.")
         self._on_outcome[Outcome.REJECT] = func
